@@ -5,7 +5,6 @@
 """
 
 from os import linesep
-from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -255,7 +254,7 @@ class Data1D(Data):
     is_components = property(
         fget=_get_is_components,
         fset=_set_is_components,
-        doc=u"""Boolean inidcating if the axis is components
+        doc=u"""Boolean indicating if the axis is components
 
         :Type: bool
         """,
