@@ -5,7 +5,6 @@
 """
 
 from os import linesep
-from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -56,6 +55,9 @@ class RequestedAxis(FrozenClass):
         operation=None,
         index=None,
         transform=None,
+        is_pattern=False,
+        rebuild_indices=None,
+        is_step=False,
         init_dict=None,
         init_str=None,
     ):
@@ -96,6 +98,12 @@ class RequestedAxis(FrozenClass):
                 index = init_dict["index"]
             if "transform" in list(init_dict.keys()):
                 transform = init_dict["transform"]
+            if "is_pattern" in list(init_dict.keys()):
+                is_pattern = init_dict["is_pattern"]
+            if "rebuild_indices" in list(init_dict.keys()):
+                rebuild_indices = init_dict["rebuild_indices"]
+            if "is_step" in list(init_dict.keys()):
+                is_step = init_dict["is_step"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
@@ -109,6 +117,9 @@ class RequestedAxis(FrozenClass):
         self.operation = operation
         self.index = index
         self.transform = transform
+        self.is_pattern = is_pattern
+        self.rebuild_indices = rebuild_indices
+        self.is_step = is_step
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -151,6 +162,15 @@ class RequestedAxis(FrozenClass):
         RequestedAxis_str += 'operation = "' + str(self.operation) + '"' + linesep
         RequestedAxis_str += "index = " + str(self.index) + linesep
         RequestedAxis_str += 'transform = "' + str(self.transform) + '"' + linesep
+        RequestedAxis_str += "is_pattern = " + str(self.is_pattern) + linesep
+        RequestedAxis_str += (
+            "rebuild_indices = "
+            + linesep
+            + str(self.rebuild_indices).replace(linesep, linesep + "\t")
+            + linesep
+            + linesep
+        )
+        RequestedAxis_str += "is_step = " + str(self.is_step) + linesep
         return RequestedAxis_str
 
     def __eq__(self, other):
@@ -180,6 +200,12 @@ class RequestedAxis(FrozenClass):
             return False
         if other.transform != self.transform:
             return False
+        if other.is_pattern != self.is_pattern:
+            return False
+        if not array_equal(other.rebuild_indices, self.rebuild_indices):
+            return False
+        if other.is_step != self.is_step:
+            return False
         return True
 
     def as_dict(self):
@@ -205,6 +231,12 @@ class RequestedAxis(FrozenClass):
         RequestedAxis_dict["operation"] = self.operation
         RequestedAxis_dict["index"] = self.index
         RequestedAxis_dict["transform"] = self.transform
+        RequestedAxis_dict["is_pattern"] = self.is_pattern
+        if self.rebuild_indices is None:
+            RequestedAxis_dict["rebuild_indices"] = None
+        else:
+            RequestedAxis_dict["rebuild_indices"] = self.rebuild_indices.tolist()
+        RequestedAxis_dict["is_step"] = self.is_step
         # The class name is added to the dict for deserialisation purpose
         RequestedAxis_dict["__class__"] = "RequestedAxis"
         return RequestedAxis_dict
@@ -223,6 +255,9 @@ class RequestedAxis(FrozenClass):
         self.operation = None
         self.index = None
         self.transform = None
+        self.is_pattern = None
+        self.rebuild_indices = None
+        self.is_step = None
 
     def _get_name(self):
         """getter of name"""
@@ -437,3 +472,64 @@ class RequestedAxis(FrozenClass):
         :Type: str
         """,
     )
+
+    def _get_is_pattern(self):
+        """getter of is_pattern"""
+        return self._is_pattern
+
+    def _set_is_pattern(self, value):
+        """setter of is_pattern"""
+        check_var("is_pattern", value, "bool")
+        self._is_pattern = value
+
+    is_pattern = property(
+        fget=_get_is_pattern,
+        fset=_set_is_pattern,
+        doc=u"""To indicate if the axis is a DataPattern
+
+        :Type: bool
+        """,
+    )
+
+    def _get_rebuild_indices(self):
+        """getter of rebuild_indices"""
+        return self._rebuild_indices
+
+    def _set_rebuild_indices(self, value):
+        """setter of rebuild_indices"""
+        if type(value) is int and value == -1:
+            value = array([])
+        elif type(value) is list:
+            try:
+                value = array(value)
+            except:
+                pass
+        check_var("rebuild_indices", value, "ndarray")
+        self._rebuild_indices = value
+
+    rebuild_indices = property(
+        fget=_get_rebuild_indices,
+        fset=_set_rebuild_indices,
+        doc=u"""Indices to rebuild pattern
+
+        :Type: ndarray
+        """,
+    )
+
+    def _get_is_step(self):
+        """getter of is_step"""
+        return self._is_step
+
+    def _set_is_step(self, value):
+        """setter of is_step"""
+        check_var("is_step", value, "bool")
+        self._is_step = value
+
+    is_step = property(
+        fget=_get_is_step,
+        fset=_set_is_step,
+        doc=u"""To indicate if the pattern axis is step (for interpolation)
+
+        :Type: bool
+        """,
+    )
