@@ -7,3 +7,6 @@ from SciDataTool.Classes.DataLinspace import DataLinspace
 from SciDataTool.Classes.DataND import DataND
 from SciDataTool.Classes.RequestedAxis import RequestedAxis
 from SciDataTool.Classes.VectorField import VectorField
+from SciDataTool.Classes.DataPattern import DataPattern
+
+__version__ = "1.1.5"
